distributions.DiscretizationReport

How a distribution was discretized, and the error that introduced.

Usage

distributions.DiscretizationReport()

Returned with the grid by Grid.local_moment, Grid.rounding and Grid.lower.

Attributes

Name Description
grid_mean Mean of the grid.
method Method: "local_moment", "rounding" or "lower".
points Number of grid points.
source_mean Mean of the source distribution.
step Grid step.
tail_mass Probability the source puts above the last grid point, lumped onto it.

grid_mean

Mean of the grid.

grid_mean: float


method

Method: "local_moment", "rounding" or "lower".

method: str


points

Number of grid points.

points: int


source_mean

Mean of the source distribution.

source_mean: float


step

Grid step.

step: float


tail_mass

Probability the source puts above the last grid point, lumped onto it.

tail_mass: float

Methods

Name Description
mean_error() grid_mean - source_mean.

mean_error()

grid_mean - source_mean.

Usage

mean_error()
Returns
float