distributions.from_json()

A distribution from a document written by to_json, as the class of

Usage

distributions.from_json(text)

its family.

Parameters

text: str

Returns

a distribution

Raises

ValueError
If the document is malformed, of another format or a newer version, or its parameters are out of range.