Identifying and filtering dominated vectors#

Dominance relations#

is_nondominated(points, /, *[, maximise, ...])

Identify dominated points according to Pareto optimality.

is_nondominated_within_sets(points, /, sets, *)

Identify dominated points according to Pareto optimality within each set.

filter_dominated(points, /, *[, maximise, ...])

Remove dominated points according to Pareto optimality.

filter_dominated_within_sets(data, /, *[, ...])

Given a matrix that represents multiple sets of points (last column gives the set index), filter dominated points within each set.

any_dominated(points, /, *[, maximise, ...])

Test whether the input points contains any (weakly-)dominated point.

pareto_rank(points, /, *[, maximise])

Rank points according to Pareto-optimality (nondominated sorting).