models.pit_from_draws()
The PIT of y under the empirical distribution of draws,
Usage
models.pit_from_draws(
draws,
y,
u=0.5,
)randomized over ties by u.
Parameters
draws: list of floaty: floatu: float = 0.5
Returns
float
The PIT of y under the empirical distribution of draws,
Usage
randomized over ties by u.
draws: list of floaty: floatu: float = 0.5 float