pricing.PortfolioPrice

Prices of a portfolio’s components and of the portfolio as a whole.

Usage

pricing.PortfolioPrice()

Returned by price_portfolio.

Attributes

Name Description
allocated Each component’s share of the portfolio price; these add up to
standalone Each component priced on its own.
total The portfolio, priced on the total of its components.

allocated

Each component’s share of the portfolio price; these add up to

allocated: list[Price]


standalone

Each component priced on its own.

standalone: list[Price]


total

The portfolio, priced on the total of its components.

total: Price

Methods

Name Description
components() Component keys, one tuple per component.
diversification() Premium saved by writing the components together: the sum of the

components()

Component keys, one tuple per component.

Usage

components()
Returns
list of tuple

diversification()

Premium saved by writing the components together: the sum of the

Usage

diversification()

standalone premiums less the portfolio premium.

Returns
float