pricing.TowerModel

A frequency and a piecewise Pareto severity that reproduce a tower,

Usage

pricing.TowerModel()

a PML curve or a set of references.

Attributes

Name Description
frequency Expected number of losses a year above the lowest threshold.
severity The fitted severity.

frequency

Expected number of losses a year above the lowest threshold.

frequency: float


severity

The fitted severity.

severity: PiecewisePareto

Methods

Name Description
excess_frequency() Expected number of losses a year above x.
layer_loss() Expected loss a year to limit xs attachment.

excess_frequency()

Expected number of losses a year above x.

Usage

excess_frequency(x)
Parameters
x: float
Returns
float

layer_loss()

Expected loss a year to limit xs attachment.

Usage

layer_loss(limit, attachment)
Parameters
limit: float
attachment: float
Returns
float