distributions.Gamma
Usage
distributions.Gamma()alpha * theta, variance alpha * theta**2.
Parameters
shape: floatscale: float
Raises
ValueError- If a parameter is not finite and positive.
Examples
>>> from prospicio.distributions import Gamma
>>> g = Gamma.from_mean_cv(1000.0, 0.5)
>>> g.shape, round(g.std(), 9)(4.0, 500.0)
Attributes
| Name | Description |
|---|---|
| scale | Scale theta. |
| shape | Shape alpha. |
scale
Scale theta.
scale: float
shape
Shape alpha.
shape: float
Methods
| Name | Description |
|---|---|
| cdf() |
Distribution function P(X <= x).
|
| from_mean_cv() | Gamma with the given mean and coefficient of variation. |
| from_mean_dispersion() |
Gamma with mean mu and GLM dispersion phi (variance
|
| layer() | Expected loss to the layer limit xs attachment. |
| layer_second_moment() | Second moment of the loss to the layer limit xs |
| layer_variance() | Variance of the loss to the layer limit xs attachment. |
| lev() |
Limited expected value E[min(X, limit)].
|
| ln_pdf() | Log density at x. |
| mean() |
Mean of the distribution (inf if it does not exist).
|
| quantile() |
Quantile: the smallest x with P(X <= x) >= p.
|
| sample() |
n draws from stream stream of the generator keyed by
|
| std() | Standard deviation of the distribution. |
| stop_loss() |
Expected excess over a retention, E[max(X - retention, 0)].
|
| survival() |
Survival function P(X > x), accurate far into the tail.
|
| variance() |
Variance of the distribution (inf if it does not exist).
|
cdf()
Distribution function P(X <= x).
Usage
cdf(x)Parameters
x: float
Returns
float
from_mean_cv()
Gamma with the given mean and coefficient of variation.
Usage
from_mean_cv(mean, cv)Parameters
mean: floatcv: float
Returns
Gamma
from_mean_dispersion()
Gamma with mean mu and GLM dispersion phi (variance
Usage
from_mean_dispersion(mean, dispersion)phi * mu**2): shape 1 / phi.
Parameters
mean: floatdispersion: float
Returns
Gamma
layer()
Expected loss to the layer limit xs attachment.
Usage
layer(limit, attachment)Parameters
limit: float-
inffor an unlimited layer. attachment: float
Returns
float
layer_second_moment()
Second moment of the loss to the layer limit xs
Usage
layer_second_moment(limit, attachment)Parameters
limit: floatattachment: float
Returns
float
layer_variance()
Variance of the loss to the layer limit xs attachment.
Usage
layer_variance(limit, attachment)Parameters
limit: floatattachment: float
Returns
float
lev()
Limited expected value E[min(X, limit)].
Usage
lev(limit)Parameters
limit: float
Returns
float
ln_pdf()
Log density at x.
Usage
ln_pdf(x)Parameters
x: float
Returns
float
mean()
Mean of the distribution (inf if it does not exist).
Usage
mean()Returns
float
quantile()
Quantile: the smallest x with P(X <= x) >= p.
Usage
quantile(p)Parameters
p: float-
Probability in
[0, 1].
Returns
float
Raises
ValueError-
If p is outside
[0, 1].
sample()
n draws from stream stream of the generator keyed by
Usage
sample(n, seed, stream=0)seed.
Parameters
n: intseed: intstream: int = 0
Returns
list of float
std()
Standard deviation of the distribution.
Usage
std()Returns
float
stop_loss()
Expected excess over a retention, E[max(X - retention, 0)].
Usage
stop_loss(retention)Parameters
retention: float
Returns
float
survival()
Survival function P(X > x), accurate far into the tail.
Usage
survival(x)Parameters
x: float
Returns
float
variance()
Variance of the distribution (inf if it does not exist).
Usage
variance()Returns
float