models.pseudo_bma_weights()
Pseudo-BMA weights, w_k proportional to exp(elpd_k); with
Usage
models.pseudo_bma_weights(
lpd,
bootstrap=True,
n_draws=1000,
seed=0,
)bootstrap=True, pseudo-BMA+ weights averaged over Bayesian-bootstrap replicates of the observations, which keeps a model that is only slightly better from taking all the weight.
Parameters
lpd: list of list of float-
One list per model, as for stacking_weights.
bootstrap: bool = Truen_draws: int = 1000-
Bootstrap replicates.
seed: int = 0- Replicate b uses stream b of seed.
Returns
list of float