pricing.alpha_between_frequency_and_layer()
The Pareto alpha at which frequency losses a year above
Usage
pricing.alpha_between_frequency_and_layer(
threshold, frequency, limit, attachment, expected_loss, truncation=None
)threshold give the layer an expected loss of expected_loss.
Parameters
threshold: floatfrequency: floatlimit: floatattachment: floatexpected_loss: floattruncation: float = None
Returns
float